@@ -94,7 +94,7 @@ Example usage as python client:
 
 """
 
-import sys, os, getopt, time, codecs
+import sys, os, getopt, time, codecs, re
 try:
     unicode_string = unicode 
     binary_string = str
@@ -152,8 +152,8 @@ log.addHandler(consoleHandler)
 log.setLevel(logging.INFO)
 
 Windows = True if platform.system() == "Windows" else False
-TikaVersion = os.getenv('TIKA_VERSION', '1.15')
-TikaJarPath = tempfile.gettempdir()
+TikaVersion = os.getenv('TIKA_VERSION', '1.16')
+TikaJarPath = os.getenv('TIKA_PATH', tempfile.gettempdir())
 TikaFilesPath = tempfile.gettempdir()
 TikaServerLogFilePath = log_path
 TikaServerJar = os.getenv(
@@ -289,7 +289,7 @@ def parse(option, urlOrPaths, serverEndpoint=ServerEndpoint, verbose=Verbose, ti
 
 def parse1(option, urlOrPath, serverEndpoint=ServerEndpoint, verbose=Verbose, tikaServerJar=TikaServerJar, 
           responseMimeType='application/json',
-          services={'meta': '/meta', 'text': '/tika', 'all': '/rmeta/text'}, rawResponse=False):
+          services={'meta': '/meta', 'text': '/tika', 'all': '/rmeta/text'}, rawResponse=False, headers=None):
     '''
     Parse the object and return extracted metadata and/or text in JSON format.
     :param option:
@@ -299,18 +299,22 @@ def parse1(option, urlOrPath, serverEndpoint=ServerEndpoint, verbose=Verbose, ti
     :param tikaServerJar:
     :param responseMimeType:
     :param services:
+    :param rawResponse:
+    :param headers:
     :return:
     '''
+    headers = headers or {}
+
     path, file_type = getRemoteFile(urlOrPath, TikaFilesPath)
+    headers.update({'Accept': responseMimeType, 'Content-Disposition': make_content_disposition_header(path)})
+
     if option not in services:
         log.warning('config option must be one of meta, text, or all; using all.')
     service = services.get(option, services['all'])
     if service == '/tika': responseMimeType = 'text/plain'
     status, response = callServer('put', serverEndpoint, service, open(path, 'rb'),
-                                  {'Accept': responseMimeType, 'Content-Disposition': make_content_disposition_header(path)},
-                                  verbose, tikaServerJar, rawResponse=rawResponse)
+                                  headers, verbose, tikaServerJar, rawResponse=rawResponse)
 
-    
     if file_type == 'remote': os.unlink(path)
     return (status, response)
 
@@ -605,6 +609,11 @@ def startServer(tikaServerJar, serverHost = ServerHost, port = Port, classpath=N
     cmd = Popen(cmd , stdout= logFile, stderr = STDOUT, shell =True)
     time.sleep(5) 
 
+def toFilename(urlOrPath):
+    value = re.sub('[^\w\s-]', '-', urlOrPath).strip().lower()
+    return re.sub('[-\s]+', '-', value).strip("-")
+
+    
 def getRemoteFile(urlOrPath, destPath):
     '''
     Fetches URL to local path or just returns absolute path.
@@ -618,7 +627,7 @@ def getRemoteFile(urlOrPath, destPath):
     elif urlp.scheme not in ('http', 'https'):
         return (urlOrPath, 'local')
     else:
-        filename = urlOrPath.rsplit('/',1)[1]
+        filename = toFilename(urlOrPath)
         destPath = destPath + '/' +filename
         log.info('Retrieving %s to %s.' % (urlOrPath, destPath))
         try:
